@@ -11,41 +11,13 @@ except ImportError, e:
   sys.exit(1)
 
 try:
+  from yapbib.version import VERSION
   from yapbib import biblist
   import query_ads.query_ads as ads
 except ImportError, e:
   print 'Import Error', __file__ ,e
   sys.exit(1)
 
-# usuarios={
-#   'Einstein':{'nombre':"Einstein,A.",'mail':'mymail@mydomain.org'},
-#   }
-# check_strict_list= ['Sanchez',u'S\xe1nchez','Suarez', u'Su\xe1rez']  # Nombres comunes, que solo se agregaran si pasan el siguiente test
-# check_strict_cond=[('affiliation', 'Bariloche',True)]
-
-# def check_conditions(item,who,what):
-#   """Check conditions on some authors (who) and only keep them if the condition 'what' is true"""
-#   autores = [ k[1] for k in item['author']] # Last Name of all authors
-  
-#   keep_item=True
-#   for aut in who:  # A quienes controlamos
-#     if aut in autores:  keep_item=False # Tenemos que controlarlos
-#   if keep_item:    return True  # No hay que controlarlos
-
-#   for w in what:
-#     if item.has_key(w[0]) != w[2]: # No existe el campo requerido (affiliation)
-#       return False
-
-#     for aut in who:  # A quienes controlamos
-#       try:
-#         j=autores.index(aut) 
-#         keep_item= False
-#       except:
-#         continue
-#       if (item[w[0]][j].find(w[1]) !=-1 ) == w[2]:
-#         return True
-#   return keep_item
-
 def main():
   '''Retrieve papers list'''
   # Declara algunas variables
@@ -53,7 +25,7 @@ def main():
   thisyear= datetime.date.today().year
 
   #########################################################################
-  parser = OptionParser()
+  parser = OptionParser(version="%prog with biblio-py-{0}".format(VERSION))
 
   parser.add_option("-o", "--output-file"
                     , help="write to FILE. Default: standard output", metavar="FILE", default='-')
@@ -77,10 +49,10 @@ def main():
                     help="Ending month as integer (Jan == 1, Dec == 12)")
   parser.add_option("--author", default=autores,
                     help="list of semicolon separated author names as last,f")
+
   parser.add_option("--author-logic", default='OR',
                     help="Logic to use to search for authors. Default: 'OR'. Use 'AND' to get only common (to all authors) articles")
-  # parser.add_option("--affiliation", default='Bariloche',
-  #                   help="affiliation words, any non-alpha-numeric character separates")
+
   parser.add_option("--proxy", default=None,
                     help="Proxy used to connect")
 
